@@ -5,7 +5,6 @@ import (
 	"path/filepath"
 
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
 )
 
 const (
@@ -18,19 +17,28 @@ type Package struct {
 }
 
 type Quasar struct {
-	language
-
-	HasVite bool
 	Vite    *Package
 	AppVite *Package
+	Language
+	HasVite bool
 }
 
 func (q *Quasar) Enabled() bool {
-	if !q.language.Enabled() {
+	q.projectFiles = []string{"quasar.config", "quasar.config.js"}
+	q.commands = []*cmd{
+		{
+			executable: "quasar",
+			args:       []string{"--version"},
+			regex:      `(?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
+		},
+	}
+	q.versionURLTemplate = "https://github.com/quasarframework/quasar/releases/tag/quasar-v{{ .Full }}"
+
+	if !q.Language.Enabled() {
 		return false
 	}
 
-	if q.language.props.GetBool(FetchDependencies, false) {
+	if q.props.GetBool(FetchDependencies, false) {
 		q.fetchDependencies()
 	}
 
@@ -41,29 +49,13 @@ func (q *Quasar) Template() string {
 	return " \uea6a {{.Full}}{{ if .HasVite }} \ueb29 {{ .Vite.Version }}{{ end }} "
 }
 
-func (q *Quasar) Init(props properties.Properties, env runtime.Environment) {
-	q.language = language{
-		env:          env,
-		props:        props,
-		projectFiles: []string{"quasar.config", "quasar.config.js"},
-		commands: []*cmd{
-			{
-				executable: "quasar",
-				args:       []string{"--version"},
-				regex:      `(?P<version>((?P<major>[0-9]+).(?P<minor>[0-9]+).(?P<patch>[0-9]+)))`,
-			},
-		},
-		versionURLTemplate: "https://github.com/quasarframework/quasar/releases/tag/quasar-v{{ .Full }}",
-	}
-}
-
 func (q *Quasar) fetchDependencies() {
-	if !q.language.env.HasFilesInDir(q.projectRoot.ParentFolder, "package-lock.json") {
+	if !q.env.HasFilesInDir(q.projectRoot.ParentFolder, "package-lock.json") {
 		return
 	}
 
 	packageFilePath := filepath.Join(q.projectRoot.ParentFolder, "package-lock.json")
-	content := q.language.env.FileContent(packageFilePath)
+	content := q.env.FileContent(packageFilePath)
 
 	var objmap map[string]json.RawMessage
 	if err := json.Unmarshal([]byte(content), &objmap); err != nil {
